General Overview
================

How, what, why

Vermouth versus Martinize 2

Installation instructions
-------------------------
How to install vermouth and martinize2

.. code-block:: bash

    pip install vermouth

Quickstart
----------
How to run Martinize 2 for the simple cases

General layout
--------------
Processors, Blocks, Links, Modifications, Force fields, Mappings

Citing
------
A publication for vermouth and martinize 2 is currently being written.
For now, please cite the relevant chapter from the thesis of Peter C Kroon:

Kroon, P.C. (2020). Martinize 2 -- VerMoUTH. *Aggregate, automate, assemble* (pp. 16-53). ISBN:
978-94-034-2581-8.